
-----------------

# Pepfeature (Alpha v 0.01): A package that consists of functions for calculating epitope/peptide features for prediction purposes



## What is it

**pepfeature** is a Python package providing fast and flexible algorithms and functions
for the feature calculation of epitope features which can be used for macine learning purposes such as classification for epitiope prediction.


## Installation

[Documentation underconstruction]

Download pepfeature folder from this repo. You can use the pepfeature/examples.py script as a playing field.

Make sure you have the modules pandas and numpy installed.

(Tested on python 3.8)

## How to use it

Ensure that any lines of code that utilize this package are encapsulated within the code block:
if __name__ == '__main__':

Please see pepfeature/examples.py for example use cases.

Also see the attached API of each function/ algorithm, for a complete documentation.


## Contributing to pepfeature

All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.
